@@ -11,8 +11,7 @@
 #include <cstdint>
 #include <array>
 
-#include <functional>
-#include <ostream>
+
 #include <string>
 
 
@@ -57,7 +56,7 @@ using GLhalfARB = unsigned short;
 using GLhalf = unsigned short;
 using GLfixed = GLint;
 using GLintptr = ptrdiff_t;
-using GLsizeiptr = ptrdiff_t;
+using GLsizeiptr = size_t;
 using GLint64 = int64_t;
 using GLuint64 = uint64_t;
 using GLintptrARB = ptrdiff_t;
@@ -112,7 +111,7 @@ namespace std
 template<>
 struct hash<gl::GLextension>
 {
-    hash<std::underlying_type<gl::GLextension>::type>::result_type operator()(const gl::GLextension & t) const
+    std::size_t operator()(const gl::GLextension & t) const
     {
         return hash<std::underlying_type<gl::GLextension>::type>()(static_cast<std::underlying_type<gl::GLextension>::type>(t));
     }
@@ -122,17 +121,6 @@ struct hash<gl::GLextension>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const GLextension & value);
-
-
-} // namespace gl
-
-
-
 namespace std
 {
 
@@ -140,7 +128,7 @@ namespace std
 template<>
 struct hash<gl::GLenum>
 {
-    hash<std::underlying_type<gl::GLenum>::type>::result_type operator()(const gl::GLenum & t) const
+    std::size_t operator()(const gl::GLenum & t) const
     {
         return hash<std::underlying_type<gl::GLenum>::type>()(static_cast<std::underlying_type<gl::GLenum>::type>(t));
     }
@@ -154,16 +142,6 @@ namespace gl
 {
 
 
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const GLenum & value);
-
-
-} // namespace gl
-
-
-namespace gl
-{
-
-
 GLBINDING_CONSTEXPR inline GLenum operator+(const GLenum & a, const std::underlying_type<GLenum>::type b)
 {
     return static_cast<GLenum>(static_cast<std::underlying_type<GLenum>::type>(a) + b);
@@ -178,6 +156,7 @@ GLBINDING_CONSTEXPR inline GLenum operator-(const GLenum & a, const std::underly
 } // namespace gl
 
 
+
 namespace gl
 {
 
@@ -247,17 +226,6 @@ GLBINDING_CONSTEXPR inline bool operator>=(std::underlying_type<GLenum>::type a,
 } // namespace gl
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const GLboolean & value);
-
-
-} // namespace gl
-
-
-
 namespace std
 {
 
@@ -265,7 +233,7 @@ namespace std
 template<>
 struct hash<gl::AttribMask>
 {
-    hash<std::underlying_type<gl::AttribMask>::type>::result_type operator()(const gl::AttribMask & t) const
+    std::size_t operator()(const gl::AttribMask & t) const
     {
         return hash<std::underlying_type<gl::AttribMask>::type>()(static_cast<std::underlying_type<gl::AttribMask>::type>(t));
     }
@@ -275,17 +243,6 @@ struct hash<gl::AttribMask>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const AttribMask & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -330,6 +287,7 @@ inline AttribMask & operator^=(AttribMask & a, const AttribMask & b)
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -337,7 +295,7 @@ namespace std
 template<>
 struct hash<gl::BufferAccessMask>
 {
-    hash<std::underlying_type<gl::BufferAccessMask>::type>::result_type operator()(const gl::BufferAccessMask & t) const
+    std::size_t operator()(const gl::BufferAccessMask & t) const
     {
         return hash<std::underlying_type<gl::BufferAccessMask>::type>()(static_cast<std::underlying_type<gl::BufferAccessMask>::type>(t));
     }
@@ -347,17 +305,6 @@ struct hash<gl::BufferAccessMask>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const BufferAccessMask & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -402,6 +349,7 @@ inline BufferAccessMask & operator^=(BufferAccessMask & a, const BufferAccessMas
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -409,7 +357,7 @@ namespace std
 template<>
 struct hash<gl::ClearBufferMask>
 {
-    hash<std::underlying_type<gl::ClearBufferMask>::type>::result_type operator()(const gl::ClearBufferMask & t) const
+    std::size_t operator()(const gl::ClearBufferMask & t) const
     {
         return hash<std::underlying_type<gl::ClearBufferMask>::type>()(static_cast<std::underlying_type<gl::ClearBufferMask>::type>(t));
     }
@@ -419,17 +367,6 @@ struct hash<gl::ClearBufferMask>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const ClearBufferMask & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -474,6 +411,7 @@ inline ClearBufferMask & operator^=(ClearBufferMask & a, const ClearBufferMask &
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -481,7 +419,7 @@ namespace std
 template<>
 struct hash<gl::ClientAttribMask>
 {
-    hash<std::underlying_type<gl::ClientAttribMask>::type>::result_type operator()(const gl::ClientAttribMask & t) const
+    std::size_t operator()(const gl::ClientAttribMask & t) const
     {
         return hash<std::underlying_type<gl::ClientAttribMask>::type>()(static_cast<std::underlying_type<gl::ClientAttribMask>::type>(t));
     }
@@ -491,17 +429,6 @@ struct hash<gl::ClientAttribMask>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const ClientAttribMask & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -546,6 +473,7 @@ inline ClientAttribMask & operator^=(ClientAttribMask & a, const ClientAttribMas
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -553,7 +481,7 @@ namespace std
 template<>
 struct hash<gl::ContextFlagMask>
 {
-    hash<std::underlying_type<gl::ContextFlagMask>::type>::result_type operator()(const gl::ContextFlagMask & t) const
+    std::size_t operator()(const gl::ContextFlagMask & t) const
     {
         return hash<std::underlying_type<gl::ContextFlagMask>::type>()(static_cast<std::underlying_type<gl::ContextFlagMask>::type>(t));
     }
@@ -563,17 +491,6 @@ struct hash<gl::ContextFlagMask>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const ContextFlagMask & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -618,6 +535,7 @@ inline ContextFlagMask & operator^=(ContextFlagMask & a, const ContextFlagMask &
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -625,7 +543,7 @@ namespace std
 template<>
 struct hash<gl::ContextProfileMask>
 {
-    hash<std::underlying_type<gl::ContextProfileMask>::type>::result_type operator()(const gl::ContextProfileMask & t) const
+    std::size_t operator()(const gl::ContextProfileMask & t) const
     {
         return hash<std::underlying_type<gl::ContextProfileMask>::type>()(static_cast<std::underlying_type<gl::ContextProfileMask>::type>(t));
     }
@@ -635,17 +553,6 @@ struct hash<gl::ContextProfileMask>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const ContextProfileMask & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -690,6 +597,7 @@ inline ContextProfileMask & operator^=(ContextProfileMask & a, const ContextProf
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -697,7 +605,7 @@ namespace std
 template<>
 struct hash<gl::FfdMaskSGIX>
 {
-    hash<std::underlying_type<gl::FfdMaskSGIX>::type>::result_type operator()(const gl::FfdMaskSGIX & t) const
+    std::size_t operator()(const gl::FfdMaskSGIX & t) const
     {
         return hash<std::underlying_type<gl::FfdMaskSGIX>::type>()(static_cast<std::underlying_type<gl::FfdMaskSGIX>::type>(t));
     }
@@ -707,17 +615,6 @@ struct hash<gl::FfdMaskSGIX>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const FfdMaskSGIX & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -762,6 +659,7 @@ inline FfdMaskSGIX & operator^=(FfdMaskSGIX & a, const FfdMaskSGIX & b)
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -769,7 +667,7 @@ namespace std
 template<>
 struct hash<gl::FragmentShaderColorModMaskATI>
 {
-    hash<std::underlying_type<gl::FragmentShaderColorModMaskATI>::type>::result_type operator()(const gl::FragmentShaderColorModMaskATI & t) const
+    std::size_t operator()(const gl::FragmentShaderColorModMaskATI & t) const
     {
         return hash<std::underlying_type<gl::FragmentShaderColorModMaskATI>::type>()(static_cast<std::underlying_type<gl::FragmentShaderColorModMaskATI>::type>(t));
     }
@@ -779,17 +677,6 @@ struct hash<gl::FragmentShaderColorModMaskATI>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const FragmentShaderColorModMaskATI & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -834,6 +721,7 @@ inline FragmentShaderColorModMaskATI & operator^=(FragmentShaderColorModMaskATI
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -841,7 +729,7 @@ namespace std
 template<>
 struct hash<gl::FragmentShaderDestMaskATI>
 {
-    hash<std::underlying_type<gl::FragmentShaderDestMaskATI>::type>::result_type operator()(const gl::FragmentShaderDestMaskATI & t) const
+    std::size_t operator()(const gl::FragmentShaderDestMaskATI & t) const
     {
         return hash<std::underlying_type<gl::FragmentShaderDestMaskATI>::type>()(static_cast<std::underlying_type<gl::FragmentShaderDestMaskATI>::type>(t));
     }
@@ -851,17 +739,6 @@ struct hash<gl::FragmentShaderDestMaskATI>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const FragmentShaderDestMaskATI & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -906,6 +783,7 @@ inline FragmentShaderDestMaskATI & operator^=(FragmentShaderDestMaskATI & a, con
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -913,7 +791,7 @@ namespace std
 template<>
 struct hash<gl::FragmentShaderDestModMaskATI>
 {
-    hash<std::underlying_type<gl::FragmentShaderDestModMaskATI>::type>::result_type operator()(const gl::FragmentShaderDestModMaskATI & t) const
+    std::size_t operator()(const gl::FragmentShaderDestModMaskATI & t) const
     {
         return hash<std::underlying_type<gl::FragmentShaderDestModMaskATI>::type>()(static_cast<std::underlying_type<gl::FragmentShaderDestModMaskATI>::type>(t));
     }
@@ -923,17 +801,6 @@ struct hash<gl::FragmentShaderDestModMaskATI>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const FragmentShaderDestModMaskATI & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -978,6 +845,7 @@ inline FragmentShaderDestModMaskATI & operator^=(FragmentShaderDestModMaskATI &
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -985,7 +853,7 @@ namespace std
 template<>
 struct hash<gl::MapBufferUsageMask>
 {
-    hash<std::underlying_type<gl::MapBufferUsageMask>::type>::result_type operator()(const gl::MapBufferUsageMask & t) const
+    std::size_t operator()(const gl::MapBufferUsageMask & t) const
     {
         return hash<std::underlying_type<gl::MapBufferUsageMask>::type>()(static_cast<std::underlying_type<gl::MapBufferUsageMask>::type>(t));
     }
@@ -995,17 +863,6 @@ struct hash<gl::MapBufferUsageMask>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const MapBufferUsageMask & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -1050,6 +907,7 @@ inline MapBufferUsageMask & operator^=(MapBufferUsageMask & a, const MapBufferUs
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -1057,7 +915,7 @@ namespace std
 template<>
 struct hash<gl::MemoryBarrierMask>
 {
-    hash<std::underlying_type<gl::MemoryBarrierMask>::type>::result_type operator()(const gl::MemoryBarrierMask & t) const
+    std::size_t operator()(const gl::MemoryBarrierMask & t) const
     {
         return hash<std::underlying_type<gl::MemoryBarrierMask>::type>()(static_cast<std::underlying_type<gl::MemoryBarrierMask>::type>(t));
     }
@@ -1067,17 +925,6 @@ struct hash<gl::MemoryBarrierMask>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const MemoryBarrierMask & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -1122,6 +969,7 @@ inline MemoryBarrierMask & operator^=(MemoryBarrierMask & a, const MemoryBarrier
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -1129,7 +977,7 @@ namespace std
 template<>
 struct hash<gl::OcclusionQueryEventMaskAMD>
 {
-    hash<std::underlying_type<gl::OcclusionQueryEventMaskAMD>::type>::result_type operator()(const gl::OcclusionQueryEventMaskAMD & t) const
+    std::size_t operator()(const gl::OcclusionQueryEventMaskAMD & t) const
     {
         return hash<std::underlying_type<gl::OcclusionQueryEventMaskAMD>::type>()(static_cast<std::underlying_type<gl::OcclusionQueryEventMaskAMD>::type>(t));
     }
@@ -1139,17 +987,6 @@ struct hash<gl::OcclusionQueryEventMaskAMD>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const OcclusionQueryEventMaskAMD & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -1194,6 +1031,7 @@ inline OcclusionQueryEventMaskAMD & operator^=(OcclusionQueryEventMaskAMD & a, c
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -1201,7 +1039,7 @@ namespace std
 template<>
 struct hash<gl::PathFontStyle>
 {
-    hash<std::underlying_type<gl::PathFontStyle>::type>::result_type operator()(const gl::PathFontStyle & t) const
+    std::size_t operator()(const gl::PathFontStyle & t) const
     {
         return hash<std::underlying_type<gl::PathFontStyle>::type>()(static_cast<std::underlying_type<gl::PathFontStyle>::type>(t));
     }
@@ -1211,17 +1049,6 @@ struct hash<gl::PathFontStyle>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const PathFontStyle & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -1266,6 +1093,7 @@ inline PathFontStyle & operator^=(PathFontStyle & a, const PathFontStyle & b)
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -1273,7 +1101,7 @@ namespace std
 template<>
 struct hash<gl::PathMetricMask>
 {
-    hash<std::underlying_type<gl::PathMetricMask>::type>::result_type operator()(const gl::PathMetricMask & t) const
+    std::size_t operator()(const gl::PathMetricMask & t) const
     {
         return hash<std::underlying_type<gl::PathMetricMask>::type>()(static_cast<std::underlying_type<gl::PathMetricMask>::type>(t));
     }
@@ -1283,17 +1111,6 @@ struct hash<gl::PathMetricMask>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const PathMetricMask & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -1338,6 +1155,7 @@ inline PathMetricMask & operator^=(PathMetricMask & a, const PathMetricMask & b)
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -1345,7 +1163,7 @@ namespace std
 template<>
 struct hash<gl::PathRenderingMaskNV>
 {
-    hash<std::underlying_type<gl::PathRenderingMaskNV>::type>::result_type operator()(const gl::PathRenderingMaskNV & t) const
+    std::size_t operator()(const gl::PathRenderingMaskNV & t) const
     {
         return hash<std::underlying_type<gl::PathRenderingMaskNV>::type>()(static_cast<std::underlying_type<gl::PathRenderingMaskNV>::type>(t));
     }
@@ -1355,17 +1173,6 @@ struct hash<gl::PathRenderingMaskNV>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const PathRenderingMaskNV & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -1410,6 +1217,7 @@ inline PathRenderingMaskNV & operator^=(PathRenderingMaskNV & a, const PathRende
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -1417,7 +1225,7 @@ namespace std
 template<>
 struct hash<gl::PerformanceQueryCapsMaskINTEL>
 {
-    hash<std::underlying_type<gl::PerformanceQueryCapsMaskINTEL>::type>::result_type operator()(const gl::PerformanceQueryCapsMaskINTEL & t) const
+    std::size_t operator()(const gl::PerformanceQueryCapsMaskINTEL & t) const
     {
         return hash<std::underlying_type<gl::PerformanceQueryCapsMaskINTEL>::type>()(static_cast<std::underlying_type<gl::PerformanceQueryCapsMaskINTEL>::type>(t));
     }
@@ -1427,17 +1235,6 @@ struct hash<gl::PerformanceQueryCapsMaskINTEL>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const PerformanceQueryCapsMaskINTEL & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -1482,6 +1279,7 @@ inline PerformanceQueryCapsMaskINTEL & operator^=(PerformanceQueryCapsMaskINTEL
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -1489,7 +1287,7 @@ namespace std
 template<>
 struct hash<gl::SyncObjectMask>
 {
-    hash<std::underlying_type<gl::SyncObjectMask>::type>::result_type operator()(const gl::SyncObjectMask & t) const
+    std::size_t operator()(const gl::SyncObjectMask & t) const
     {
         return hash<std::underlying_type<gl::SyncObjectMask>::type>()(static_cast<std::underlying_type<gl::SyncObjectMask>::type>(t));
     }
@@ -1499,17 +1297,6 @@ struct hash<gl::SyncObjectMask>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const SyncObjectMask & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -1554,6 +1341,7 @@ inline SyncObjectMask & operator^=(SyncObjectMask & a, const SyncObjectMask & b)
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -1561,7 +1349,7 @@ namespace std
 template<>
 struct hash<gl::TextureStorageMaskAMD>
 {
-    hash<std::underlying_type<gl::TextureStorageMaskAMD>::type>::result_type operator()(const gl::TextureStorageMaskAMD & t) const
+    std::size_t operator()(const gl::TextureStorageMaskAMD & t) const
     {
         return hash<std::underlying_type<gl::TextureStorageMaskAMD>::type>()(static_cast<std::underlying_type<gl::TextureStorageMaskAMD>::type>(t));
     }
@@ -1571,17 +1359,6 @@ struct hash<gl::TextureStorageMaskAMD>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const TextureStorageMaskAMD & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -1626,6 +1403,7 @@ inline TextureStorageMaskAMD & operator^=(TextureStorageMaskAMD & a, const Textu
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -1633,7 +1411,7 @@ namespace std
 template<>
 struct hash<gl::UseProgramStageMask>
 {
-    hash<std::underlying_type<gl::UseProgramStageMask>::type>::result_type operator()(const gl::UseProgramStageMask & t) const
+    std::size_t operator()(const gl::UseProgramStageMask & t) const
     {
         return hash<std::underlying_type<gl::UseProgramStageMask>::type>()(static_cast<std::underlying_type<gl::UseProgramStageMask>::type>(t));
     }
@@ -1643,17 +1421,6 @@ struct hash<gl::UseProgramStageMask>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const UseProgramStageMask & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -1698,6 +1465,7 @@ inline UseProgramStageMask & operator^=(UseProgramStageMask & a, const UseProgra
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -1705,7 +1473,7 @@ namespace std
 template<>
 struct hash<gl::VertexHintsMaskPGI>
 {
-    hash<std::underlying_type<gl::VertexHintsMaskPGI>::type>::result_type operator()(const gl::VertexHintsMaskPGI & t) const
+    std::size_t operator()(const gl::VertexHintsMaskPGI & t) const
     {
         return hash<std::underlying_type<gl::VertexHintsMaskPGI>::type>()(static_cast<std::underlying_type<gl::VertexHintsMaskPGI>::type>(t));
     }
@@ -1715,17 +1483,6 @@ struct hash<gl::VertexHintsMaskPGI>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const VertexHintsMaskPGI & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -1770,6 +1527,7 @@ inline VertexHintsMaskPGI & operator^=(VertexHintsMaskPGI & a, const VertexHints
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -1777,7 +1535,7 @@ namespace std
 template<>
 struct hash<gl::UnusedMask>
 {
-    hash<std::underlying_type<gl::UnusedMask>::type>::result_type operator()(const gl::UnusedMask & t) const
+    std::size_t operator()(const gl::UnusedMask & t) const
     {
         return hash<std::underlying_type<gl::UnusedMask>::type>()(static_cast<std::underlying_type<gl::UnusedMask>::type>(t));
     }
@@ -1787,17 +1545,6 @@ struct hash<gl::UnusedMask>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const UnusedMask & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -1842,6 +1589,7 @@ inline UnusedMask & operator^=(UnusedMask & a, const UnusedMask & b)
 } // namespace gl
 
 
+
 namespace std
 {
 
@@ -1849,7 +1597,7 @@ namespace std
 template<>
 struct hash<gl::BufferStorageMask>
 {
-    hash<std::underlying_type<gl::BufferStorageMask>::type>::result_type operator()(const gl::BufferStorageMask & t) const
+    std::size_t operator()(const gl::BufferStorageMask & t) const
     {
         return hash<std::underlying_type<gl::BufferStorageMask>::type>()(static_cast<std::underlying_type<gl::BufferStorageMask>::type>(t));
     }
@@ -1859,17 +1607,6 @@ struct hash<gl::BufferStorageMask>
 } // namespace std
 
 
-namespace gl
-{
-
-
-GLBINDING_API std::ostream & operator<<(std::ostream & stream, const BufferStorageMask & value);
-
-
-} // namespace gl
-
-
-
 namespace gl
 {
 
@@ -1913,3 +1650,4 @@ inline BufferStorageMask & operator^=(BufferStorageMask & a, const BufferStorage
 
 } // namespace gl
 
+
